==> haskell-monadprompt-1.0.0.5-3-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-monadprompt.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 MonadPrompt
version:              1.0.0.5
visibility:           public
id:                   MonadPrompt-1.0.0.5-GcXKT497G1U1Gu0Zf8sWqX
key:                  MonadPrompt-1.0.0.5-GcXKT497G1U1Gu0Zf8sWqX
license:              BSD-3-Clause
copyright:            (c) 2008 Ryan Ingram & Bertram Felgenhauer & Cale Gibbard
maintainer:           ryani.spam@gmail.com
author:               Ryan Ingram
stability:            experimental
synopsis:             MonadPrompt, implementation & examples
description:
    \"Prompting\" monad that allows splitting the description
    of a computation from the implementation of the effects
    used in that computation.
    <http://www.haskell.org/pipermail/haskell-cafe/2008-January/038301.html>

category:             Control
abi:                  14c676acab2f648a2713f929983b28cf
exposed:              True
exposed-modules:      Control.Monad.Prompt
import-dirs:          /usr/lib/ghc-8.10.4/site-local/MonadPrompt-1.0.0.5
library-dirs:         /usr/lib/ghc-8.10.4/site-local/MonadPrompt-1.0.0.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/MonadPrompt-1.0.0.5
hs-libraries:         HSMonadPrompt-1.0.0.5-GcXKT497G1U1Gu0Zf8sWqX
depends:              base-4.14.1.0 mtl-2.2.2
haddock-interfaces:   /usr/share/doc/haskell-monadprompt/html/MonadPrompt.haddock
haddock-html:         /usr/share/doc/haskell-monadprompt/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-monadprompt-1.0.0.5-5-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-monadprompt.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 MonadPrompt
version:              1.0.0.5
visibility:           public
id:                   MonadPrompt-1.0.0.5-3aQW64UgU7vGFzuL1w1DPh
key:                  MonadPrompt-1.0.0.5-3aQW64UgU7vGFzuL1w1DPh
license:              BSD-3-Clause
copyright:            (c) 2008 Ryan Ingram & Bertram Felgenhauer & Cale Gibbard
maintainer:           ryani.spam@gmail.com
author:               Ryan Ingram
stability:            experimental
synopsis:             MonadPrompt, implementation & examples
description:
    \"Prompting\" monad that allows splitting the description
    of a computation from the implementation of the effects
    used in that computation.
    <http://www.haskell.org/pipermail/haskell-cafe/2008-January/038301.html>

category:             Control
abi:                  cd93b205e835b9a727cec1f50ae992c7
exposed:              True
exposed-modules:      Control.Monad.Prompt
import-dirs:          /usr/lib/ghc-9.0.1/site-local/MonadPrompt-1.0.0.5
library-dirs:         /usr/lib/ghc-9.0.1/site-local/MonadPrompt-1.0.0.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/MonadPrompt-1.0.0.5
hs-libraries:         HSMonadPrompt-1.0.0.5-3aQW64UgU7vGFzuL1w1DPh
depends:              base-4.15.0.0 mtl-2.2.2
haddock-interfaces:   /usr/share/doc/haskell-monadprompt/html/MonadPrompt.haddock
haddock-html:         /usr/share/doc/haskell-monadprompt/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
